@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtk_freetype.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * When using 'fmt' in VTK, this header enables use to use either the fmt
  * version provided by VTK or an externally built version based on compile time
@@ -43,7 +31,7 @@
 #if VTK_MODULE_USE_EXTERNAL_VTK_fmt
 # define VTK_FMT(header) <header>
 #else
-# define VTK_FMT(header) <vtk##header>
+# define VTK_FMT(header) <vtkfmt/vtk##header>
 #endif
 
 #endif // #ifndef vtk_fmt_h
